/**
 * Anticrm Platform Foundation Types
 * @packageDocumentation
 */
/**
 * Platform Resource Identifier (PRI)
 *
 * @remarks
 *
 * Almost anything in the Anticrm Platform is a `Resource`. Resources referenced by Platform Resource Identifier (PRI).
 *
 * TODO: understand Resource better. Is this just a `platform` thing or should be in `core` as well
 *
 * 'Resource' is simply any JavaScript object. There is a plugin exists, which 'resolve' PRI into actual object.
 * This is a difference from Metadata. Metadata object 'resolved' by Platform instance, so we may consider Metadata as
 * a Resource, provided by Platform itself. Because there is always a plugin, which resolve `Resource` resolution is
 * asynchronous process.
 *
 * `Resource` is a string of `kind:plugin.id` format. Since Metadata is a kind of Resource.
 * Metadata also can be resolved using resource API.
 *
 * @example
 * ```typescript
 *   `class:contact.Person` as Resource<Class<Person>> // database object with id === `class:contact.Person`
 *   `string:class.ClassLabel` as Resource<string> // translated string according to current language and i18n settings
 *   `asset:ui.Icons` as Resource<URL> // URL to SVG sprites
 *   `easyscript:2+2` as Resource<() => number> // function
 * ```
 *
 * @public
 */
export declare type Resource<T> = string & {
    __resource: T;
};
/**
 * Status severity
 * @public
 */
export declare enum Severity {
    OK = 0,
    INFO = 1,
    WARNING = 2,
    ERROR = 3
}
export declare enum PlatformStatusCodes {
    AUTHENTICATON_OK = 101,
    AUTHENTICATON_REQUIRED = 102
}
/**
 * Status of an operation
 * @public
 */
export declare class Status {
    severity: Severity;
    code: number;
    message: string;
    constructor(severity: Severity, code: number, message: string);
}
/**
 * Error object wrapping `Status`
 * @public
 */
export declare class PlatformError extends Error {
    readonly status: Status;
    constructor(status: Status);
}
