"use strict";
//
// Copyright © 2020, 2021 Anticrm Platform Contributors.
//
// Licensed under the Eclipse Public License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License. You may
// obtain a copy of the License at https://www.eclipse.org/legal/epl-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//
// See the License for the specific language governing permissions and
// limitations under the License.
//
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlatformError = exports.Status = exports.PlatformStatusCodes = exports.Severity = void 0;
/**
 * Status severity
 * @public
 */
var Severity;
(function (Severity) {
    Severity[Severity["OK"] = 0] = "OK";
    Severity[Severity["INFO"] = 1] = "INFO";
    Severity[Severity["WARNING"] = 2] = "WARNING";
    Severity[Severity["ERROR"] = 3] = "ERROR";
})(Severity = exports.Severity || (exports.Severity = {}));
var PlatformStatusCodes;
(function (PlatformStatusCodes) {
    PlatformStatusCodes[PlatformStatusCodes["AUTHENTICATON_OK"] = 101] = "AUTHENTICATON_OK";
    PlatformStatusCodes[PlatformStatusCodes["AUTHENTICATON_REQUIRED"] = 102] = "AUTHENTICATON_REQUIRED";
})(PlatformStatusCodes = exports.PlatformStatusCodes || (exports.PlatformStatusCodes = {}));
/**
 * Status of an operation
 * @public
 */
class Status {
    constructor(severity, code, message) {
        this.severity = severity;
        this.code = code;
        this.message = message;
    }
}
exports.Status = Status;
/**
 * Error object wrapping `Status`
 * @public
 */
class PlatformError extends Error {
    constructor(status) {
        super(status.message);
        this.status = status;
    }
}
exports.PlatformError = PlatformError;
